Balladeer
:::::::::

This is a Python package for creating web-enabled interactive fiction.

Documentation
+++++++++++++

Documentation is included in the package. You can find both plain text and HTML::

    pip download balladeer

If you'd rather browse online, you can do so `here
<https://balladeer.readthedocs.io/en/latest/index.html>`_.

